# Form implementation generated from reading ui file 'resultsWidgetTpl.ui'
#
# Created by: PyQt6 UI code generator 6.2.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(837, 324)
        self.gridLayout = QtWidgets.QGridLayout(Form)
        self.gridLayout.setObjectName("gridLayout")
        self.lyt_paging = QtWidgets.QHBoxLayout()
        self.lyt_paging.setObjectName("lyt_paging")
        self.label_status = QtWidgets.QLabel(Form)
        self.label_status.setMinimumSize(QtCore.QSize(24, 24))
        self.label_status.setText("")
        self.label_status.setPixmap(QtGui.QPixmap("icons:loading.gif"))
        self.label_status.setObjectName("label_status")
        self.lyt_paging.addWidget(self.label_status)
        self.button_first_page = QtWidgets.QPushButton(Form)
        self.button_first_page.setMaximumSize(QtCore.QSize(30, 16777215))
        self.button_first_page.setObjectName("button_first_page")
        self.lyt_paging.addWidget(self.button_first_page)
        self.button_previous_page = QtWidgets.QPushButton(Form)
        self.button_previous_page.setMaximumSize(QtCore.QSize(30, 16777215))
        self.button_previous_page.setObjectName("button_previous_page")
        self.lyt_paging.addWidget(self.button_previous_page)
        self.input_current_page = QtWidgets.QSpinBox(Form)
        self.input_current_page.setMinimumSize(QtCore.QSize(75, 0))
        self.input_current_page.setMinimum(1)
        self.input_current_page.setMaximum(9999999)
        self.input_current_page.setObjectName("input_current_page")
        self.lyt_paging.addWidget(self.input_current_page)
        self.button_next_page = QtWidgets.QPushButton(Form)
        self.button_next_page.setMaximumSize(QtCore.QSize(30, 16777215))
        self.button_next_page.setObjectName("button_next_page")
        self.lyt_paging.addWidget(self.button_next_page)
        self.button_last_page = QtWidgets.QPushButton(Form)
        self.button_last_page.setMaximumSize(QtCore.QSize(30, 16777215))
        self.button_last_page.setObjectName("button_last_page")
        self.lyt_paging.addWidget(self.button_last_page)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Minimum)
        self.lyt_paging.addItem(spacerItem)
        self.input_category = QtWidgets.QComboBox(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.input_category.sizePolicy().hasHeightForWidth())
        self.input_category.setSizePolicy(sizePolicy)
        self.input_category.setMinimumSize(QtCore.QSize(150, 0))
        self.input_category.setLayoutDirection(QtCore.Qt.LayoutDirection.RightToLeft)
        self.input_category.setObjectName("input_category")
        self.lyt_paging.addWidget(self.input_category)
        self.input_filler = QtWidgets.QLineEdit(Form)
        self.input_filler.setMinimumSize(QtCore.QSize(200, 0))
        self.input_filler.setObjectName("input_filler")
        self.lyt_paging.addWidget(self.input_filler)
        self.button_filter_apply = QtWidgets.QPushButton(Form)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap("icons:arrow-right.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
        self.button_filter_apply.setIcon(icon)
        self.button_filter_apply.setObjectName("button_filter_apply")
        self.lyt_paging.addWidget(self.button_filter_apply)
        self.button_filter_reset = QtWidgets.QPushButton(Form)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap("icons:reset.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
        self.button_filter_reset.setIcon(icon1)
        self.button_filter_reset.setObjectName("button_filter_reset")
        self.lyt_paging.addWidget(self.button_filter_reset)
        self.gridLayout.addLayout(self.lyt_paging, 0, 0, 1, 1)
        self.view_results = QtWidgets.QTableView(Form)
        self.view_results.setStyleSheet("")
        self.view_results.setSizeAdjustPolicy(QtWidgets.QAbstractScrollArea.SizeAdjustPolicy.AdjustToContents)
        self.view_results.setSelectionMode(QtWidgets.QAbstractItemView.SelectionMode.ContiguousSelection)
        self.view_results.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectionBehavior.SelectRows)
        self.view_results.setTextElideMode(QtCore.Qt.TextElideMode.ElideNone)
        self.view_results.setSortingEnabled(True)
        self.view_results.setObjectName("view_results")
        self.view_results.horizontalHeader().setSortIndicatorShown(True)
        self.view_results.horizontalHeader().setStretchLastSection(True)
        self.gridLayout.addWidget(self.view_results, 1, 0, 1, 1)

        self.retranslateUi(Form)
        self.button_previous_page.clicked.connect(Form.previous_page) # type: ignore
        self.button_next_page.clicked.connect(Form.next_page) # type: ignore
        self.button_first_page.clicked.connect(Form.first_page) # type: ignore
        self.button_last_page.clicked.connect(Form.last_page) # type: ignore
        self.input_current_page.valueChanged['int'].connect(Form.set_page) # type: ignore
        self.input_category.currentIndexChanged['int'].connect(Form.column_filter_changed) # type: ignore
        self.button_filter_apply.clicked.connect(Form.filter_results) # type: ignore
        self.button_filter_reset.clicked.connect(Form.filter_reset) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.button_first_page.setToolTip(_translate("Form", "Jump to first page"))
        self.button_first_page.setText(_translate("Form", "|<"))
        self.button_previous_page.setToolTip(_translate("Form", "Jump to previous page"))
        self.button_previous_page.setText(_translate("Form", "<"))
        self.input_current_page.setToolTip(_translate("Form", "Current page / Total pages"))
        self.button_next_page.setToolTip(_translate("Form", "Jump to next page"))
        self.button_next_page.setText(_translate("Form", ">"))
        self.button_last_page.setToolTip(_translate("Form", "Jump to last page"))
        self.button_last_page.setText(_translate("Form", ">|"))
        self.input_category.setToolTip(_translate("Form", "Select column to filter on"))
        self.input_filler.setPlaceholderText(_translate("Form", "Filter by regexp"))
        self.button_filter_apply.setToolTip(_translate("Form", "Apply filter"))
        self.button_filter_apply.setText(_translate("Form", " Apply"))
        self.button_filter_reset.setToolTip(_translate("Form", "Reset filters"))
        self.button_filter_reset.setText(_translate("Form", " Reset"))
